body { 
    background: #FFFFFF; 
}

h1, h2, h3, h4, h5 { 
    color: #800000; 
    font-family: sans-serif; 
}

span.term { 
    font-weight: bold; 
}

div.sidebar { 
    background: #F0F0F0; 
    border: 1px solid gray; 
    padding: 5px; 
    margin: 20px; 
}

pre.programlisting { 
    background: #F0F0F0; 
    border: 1px solid gray; 
    padding: 2px; 
    font-size: 10pt;
    white-space: pre;
}
